# jsonschema_inference
Fast Schema Inferencing of JSON from jsonl file or web API. 

# TODO:

- [ ] Try to convert the schema inference result to the Draft 7 Json schema specification. (It is the most popular schema format currently) 